# Track Reference

::: geo_track_analyzer.track.GPXFileTrack
::: geo_track_analyzer.track.FITTrack
::: geo_track_analyzer.track.ByteTrack
::: geo_track_analyzer.track.PyTrack
::: geo_track_analyzer.track.SegmentTrack

